==> runtime-3.0.151-sources.jar: com/cloudimpl/outstack/runtime/domain/Role.java <==
/*
 * Copyright 2021 nuwan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudimpl.outstack.runtime.domain;

import com.cloudimpl.outstack.runtime.domainspec.*;

/**
 *
 * @author nuwan
 */
@EntityMeta(plural = "Roles" , version = "v1")
public class Role extends RootEntity implements ITenantOptional {

    @Id
    private final String roleName;
    private final String tenantId;
    
    public Role(String roleName,String tenantId) {
        this.roleName = roleName;
        this.tenantId = tenantId;
    }

    public String getRoleName() {
        return roleName;
    }

    @Override
    public String entityId() {
        return roleName;
    }

    private void applyEvent(RoleCreated created) {
        
    }

    @Override
    protected void apply(Event event) {
        switch (event.getClass().getSimpleName()) {
            case "RoleCreated": {
                applyEvent((RoleCreated) event);
                break;
            }
            default: {
                throw new DomainEventException(DomainEventException.ErrorCode.UNHANDLED_EVENT, "unhandled event:" + event.getClass().getName());
            }
        }
    }

    @Override
    public String idField() {
        return "roleName";
    }

}

==> runtime-4.0.544-sources.jar: com/cloudimpl/outstack/runtime/domain/Role.java <==
/*
 * Copyright 2021 nuwan.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudimpl.outstack.runtime.domain;

import com.cloudimpl.outstack.runtime.domainspec.*;

/**
 *
 * @author nuwan
 */
@EntityMeta(plural = "Roles" , version = "v1")
public class Role extends RootEntity implements ITenantOptional {

    @Id
    private final String roleName;
    private final String tenantId;
    private  String type;
    
    public Role(String roleName, String tenantId) {
        this.roleName = roleName;
        this.tenantId = tenantId;
    }

    public String getRoleName() {
        return roleName;
    }

    @Override
    public String getTenantId() {return tenantId;}

    public String getType() { return type;}

    @Override
    public String entityId() {
        return roleName;
    }

    private void applyEvent(RoleCreated created) {
        this.type = created.getType();
    }

    @Override
    protected void apply(Event event) {
        switch (event.getClass().getSimpleName()) {
            case "RoleCreated": {
                applyEvent((RoleCreated) event);
                break;
            }
            default: {
                throw new DomainEventException(DomainEventException.ErrorCode.UNHANDLED_EVENT, "unhandled event:" + event.getClass().getName());
            }
        }
    }

    @Override
    public String idField() {
        return "roleName";
    }

}
